import { BscScanURL } from "@zoidpay-tech/zoidpay-blockchain-helpers/dist/src/models/Bsc/BscScanUrl";
import { Request, Response } from "express";
import { network } from "hardhat";
import {
  buildCreateBscNftCollection,
  buildCreateBscToken,
  buildGetAbiBsc,
  buildGetAbiFunctionsBsc,
  buildmintNftBscTokenCollection,
  buildTransferBscToken,
  buildVerifyBscToken,
} from "../transactionBuilderBsc";

export const transferBscToken = async (req: Request, res: Response) => {
  const address = req.body.address;
  const networkProvider = req.body.networkProvider;

  const tx = await buildTransferBscToken(req.body, address, networkProvider);

  res.send(tx);
};

export const createBscToken = async (req: Request, res: Response) => {
  const address = req.body.address;
  const networkProvider = req.body.networkProvider;

  const tx = await buildCreateBscToken(req.body, address, networkProvider);

  res.send(tx);
};

export const createBscNftCollection = async (req: Request, res: Response) => {
  const address = req.body.address;
  const networkProvider = req.body.networkProvider;

  const tx = await buildCreateBscNftCollection(
    req.body,
    address,
    networkProvider
  );

  res.send(tx);
};

export const mintBscNft = async (req: Request, res: Response) => {
  const address = req.body.address;
  const networkProvider = req.body.networkProvider;

  const tx = await buildmintNftBscTokenCollection(
    req.body,
    address,
    networkProvider
  );

  res.send(tx);
};

export const getAbiFunctionsBsc = async (req: Request, res: Response) => {
  try {
    const address = req.body.address;
    const networkProvider = req.body.networkProvider;

    const tx = await buildGetAbiFunctionsBsc(
      address,
      networkProvider,
      req.body.smartContractAddress
    );

    res.send(tx);
  } catch (err) {
    console.log(err);
  }
};

export const getAbiBsc = async (req: Request, res: Response) => {
  try {
    const address = req.body.address;
    const networkProvider = req.body.networkProvider;

    const tx = await buildGetAbiBsc(
      address,
      networkProvider,
      req.body.smartContractAddress,
    );

    res.send(tx);
  } catch (err) {
    console.log(err);
  }
};

export const verifyBscToken = async (req: Request, res: Response) => {
  try {
    const address = req.body.address;
    const networkProvider = req.body.networkProvider;

    const tx = await buildVerifyBscToken(req.body, address, networkProvider);

    res.send(tx);
  } catch (err) {
    console.log(err);
  }
};

export const verifyBscNft = async (req: Request, res: Response) => {
  try {
    const address = req.body.address;
    const networkProvider = req.body.networkProvider;

    const tx = await buildVerifyBscToken(req.body, address, networkProvider);

    res.send(tx);
  } catch (err) {
    console.log(err);
  }
};
