import { Request, Response } from "express";
import {
  abiFunctions,
  buildCreateEthToken,
  buildCreateEthTokenCollection,
  buildGetAbiEth,
  buildmintNftEthTokenCollection,
  buildTransferEthToken,
  buildVerifyEthNft,
  buildVerifyEthToken,
} from "../transactionBuilderEthereum";

export const transferEthToken = async (req: Request, res: Response) => {
  const address = req.body.address;
  const networkProvider = req.body.networkProvider;
  const chainId = req.body.chainId;
  const privateKey = req.body.privateKey;

  const tx = await buildTransferEthToken(
    req.body,
    address,
    networkProvider,
    chainId,
    privateKey
  );

  res.send(tx);
};

export const createEthToken = async (req: Request, res: Response) => {
  try {
    const address = req.body.address;
    const networkProvider = req.body.networkProvider;
    const chainId = req.body.chainId;
    const privateKey = req.body.privateKey;

    const tx = await buildCreateEthToken(
      req.body,
      address,
      networkProvider,
      chainId,
      privateKey
    );

    res.send(tx);
  } catch (err) {
    console.log(err);
  }
};

export const nftCreateCollection = async (req: Request, res: Response) => {
  try {
    const address = req.body.address;
    const networkProvider = req.body.networkProvider;
    const chainId = req.body.chainId;
    const privateKey = req.body.privateKey;

    const tx = await buildCreateEthTokenCollection(
      req.body,
      address,
      networkProvider,
      chainId
      // change body
    );

    res.send(tx);
  } catch (err) {
    console.log(err);
  }
};

export const mintNftEth = async (req: Request, res: Response) => {
  try {
    const address = req.body.address;
    const networkProvider = req.body.networkProvider;
    const chainId = req.body.chainId;

    const tx = await buildmintNftEthTokenCollection(
      req.body,
      address,
      networkProvider,
      chainId
      // change body
    );

    res.send(tx);
  } catch (err) {
    console.log(err);
  }
};

export const verifyEthNft = async (req: Request, res: Response) => {
  try {
    const address = req.body.address;
    const networkProvider = req.body.networkProvider;
    const chainId = req.body.chainId;

    const tx = await buildVerifyEthNft(
      req.body,
      address,
      networkProvider,
      chainId
      // change body
    );

    res.send(tx);
  } catch (err) {
    console.log(err);
  }
};

export const verifyEthToken = async (req: Request, res: Response) => {
  try {
    const address = req.body.address;
    const networkProvider = req.body.networkProvider;
    const chainId = req.body.chainId;

    const tx = await buildVerifyEthToken(
      req.body,
      address,
      networkProvider,
      chainId
      // change body
    );

    res.send(tx);
  } catch (err) {
    console.log(err);
  }
};

export const getAbiFunctions = async (req: Request, res: Response) => {
  try {
    const address = req.body.address;
    const networkProvider = req.body.networkProvider;
    const chainId = req.body.chainId;

    const tx = await abiFunctions(
      address,
      networkProvider,
      chainId,
      req.body.smartContractAddress,
      req.body.etherscanURL
    );

    res.send(tx);
  } catch (err) {
    console.log(err);
  }
};

export const getAbiEth = async (req: Request, res: Response) => {
  try {
    const address = req.body.address;
    const networkProvider = req.body.networkProvider;
    const chainId = req.body.chainId;

    const tx = await buildGetAbiEth(
      address,
      networkProvider,
      chainId,
      req.body.smartContractAddress,
      req.body.etherscanURL
    );

    res.send(tx);
  } catch (err) {
    console.log(err);
  }
};
