import { Polygon } from "@zoidpay-tech/zoidpay-blockchain-helpers";
import { Request, Response } from "express";
import {
  buildCreateMaticToken,
  buildCreateNftMaticCollection,
  buildGetAbiMatic,
  buildMaticMintToken,
  buildMaticNftVerify,
  buildMaticTokenVerify,
  buildTransferMaticToken,
} from "../transactionBuilderMatic";

export const transferMaticToken = async (req: Request, res: Response) => {
  const address = req.body.address;
  const networkProvider = req.body.networkProvider;

  const tx = await buildTransferMaticToken(req.body, address, networkProvider);

  res.send(tx);
};

export const createMaticToken = async (req: Request, res: Response) => {
  const address = req.body.address;
  const networkProvider = req.body.networkProvider;

  const tx = await buildCreateMaticToken(req.body, address, networkProvider);

  res.send(tx);
};

export const maticTokenVerify = async (req: Request, res: Response) => {
  const address = req.body.address;
  const networkProvider = req.body.networkProvider;

  const tx = await buildMaticTokenVerify(req.body, address, networkProvider);

  res.send(tx);
};

export const createMaticNftCollection = async (req: Request, res: Response) => {
  const address = req.body.address;
  const networkProvider = req.body.networkProvider;

  const tx = await buildCreateNftMaticCollection(
    req.body,
    address,
    networkProvider
  );

  res.send(tx);
};

export const maticMintToken = async (req: Request, res: Response) => {
  const address = req.body.address;
  const networkProvider = req.body.networkProvider;

  const tx = await buildMaticMintToken(req.body, address, networkProvider);

  res.send(tx);
};

export const maticNftVerify = async (req: Request, res: Response) => {
  const address = req.body.address;
  const networkProvider = req.body.networkProvider;

  const tx = await buildMaticNftVerify(req.body, address, networkProvider);

  res.send(tx);
};

export const getAbiMatic = async (req: Request, res: Response) => {
  try {
    const address = req.body.address;
    const networkProvider = req.body.networkProvider;
    const smartContractAddress = req.body.smartContractAddress;

    const tx = await buildGetAbiMatic(
      address,
      networkProvider,
      smartContractAddress,
    );

    res.send(tx);
  } catch (err) {
    console.log(err);
  }
};

export const getAbiFunctionsMatic = async (req: Request, res: Response) => {
  try {
    const address = req.body.address;
    const networkProvider = req.body.networkProvider;
    const smartContractAddress = req.body.smartContractAddress;

    const polygon = new Polygon.Client({
      networkProvider,
      address,
    });

    const abi = await polygon.getAbiFunctions(
      smartContractAddress,
    );

    res.send(abi);
  } catch (err) {
    console.log(err);
  }
};
