import { Elrond } from "@zoidpay-tech/zoidpay-blockchain-helpers";

export const buildIssue = async (
  body: Elrond.models.ESDTIssueTokenData,
  address: string,
  networkProvider: Elrond.models.NetworkProvider
) => {
  const elrondInstance = new Elrond.Client({
    address: address,
    networkProvider,
  });

  const tx = await elrondInstance.buildTransaction({
    transactionCategory: Elrond.models.TransactionCategory.ESDT,
    transactionType: Elrond.models.ESDTFunctions.issue,
    operationsData: body,
  });
  console.log(`Transaction built: ${JSON.stringify(tx)}`);

  return tx;
};

export const buildTransfer = async (
  body: Elrond.models.ESDTTransferData,
  address: string,
  networkProvider: Elrond.models.NetworkProvider
) => {
  const elrondInstance = new Elrond.Client({
    address: address,
    networkProvider,
  });

  const tx = await elrondInstance.buildTransaction({
    transactionCategory: Elrond.models.TransactionCategory.ESDT,
    transactionType: Elrond.models.ESDTFunctions.transfer,
    operationsData: body,
  });
  console.log(`Transaction built: ${JSON.stringify(tx)}`);

  return tx;
};

export const buildSetRole = async (
  body: Elrond.models.ESDTSetSpecialRoleData,
  address: string,
  networkProvider: Elrond.models.NetworkProvider
) => {
  const elrondInstance = new Elrond.Client({
    address: address,
    networkProvider,
  });

  const tx = await elrondInstance.buildTransaction({
    transactionCategory: Elrond.models.TransactionCategory.ESDT,
    transactionType: Elrond.models.ESDTFunctions.setSpecialRole,
    operationsData: body,
  });
  console.log(`Transaction built: ${JSON.stringify(tx)}`);

  return tx;
};

export const buildUnSetRole = async (
  body: Elrond.models.ESDTUnsetSpecialRoleData,
  address: string,
  networkProvider: Elrond.models.NetworkProvider
) => {
  const elrondInstance = new Elrond.Client({
    address: address,
    networkProvider,
  });

  const tx = await elrondInstance.buildTransaction({
    transactionCategory: Elrond.models.TransactionCategory.ESDT,
    transactionType: Elrond.models.ESDTFunctions.unSetSpecialRole,
    operationsData: body,
  });
  console.log(`Transaction built: ${JSON.stringify(tx)}`);

  return tx;
};

export const buildLocalMint = async (
  body: Elrond.models.ESDTLocalMintData,
  address: string,
  networkProvider: Elrond.models.NetworkProvider
) => {
  const elrondInstance = new Elrond.Client({
    address: address,
    networkProvider,
  });

  const tx = await elrondInstance.buildTransaction({
    transactionCategory: Elrond.models.TransactionCategory.ESDT,
    transactionType: Elrond.models.ESDTFunctions.localMint,
    operationsData: body,
  });
  console.log(`Transaction built: ${JSON.stringify(tx)}`);

  return tx;
};

export const buildLocalBurn = async (
  body: Elrond.models.ESDTLocalBurnData,
  address: string,
  networkProvider: Elrond.models.NetworkProvider
) => {
  const elrondInstance = new Elrond.Client({
    address: address,
    networkProvider,
  });

  const tx = await elrondInstance.buildTransaction({
    transactionCategory: Elrond.models.TransactionCategory.ESDT,
    transactionType: Elrond.models.ESDTFunctions.localBurn,
    operationsData: body,
  });
  console.log(`Transaction built: ${JSON.stringify(tx)}`);

  return tx;
};

export const buildPause = async (
  body: Elrond.models.ESDTPauseData,
  address: string,
  networkProvider: Elrond.models.NetworkProvider
) => {
  const elrondInstance = new Elrond.Client({
    address: address,
    networkProvider,
  });

  const tx = await elrondInstance.buildTransaction({
    transactionCategory: Elrond.models.TransactionCategory.ESDT,
    transactionType: Elrond.models.ESDTFunctions.pause,
    operationsData: body,
  });

  return tx;
};

export const buildUnPause = async (
  body: Elrond.models.ESDTUnPauseData,
  address: string,
  networkProvider: Elrond.models.NetworkProvider
) => {
  const elrondInstance = new Elrond.Client({
    address: address,
    networkProvider,
  });

  const tx = await elrondInstance.buildTransaction({
    transactionCategory: Elrond.models.TransactionCategory.ESDT,
    transactionType: Elrond.models.ESDTFunctions.unPause,
    operationsData: body,
  });

  return tx;
};

export const buildFreeze = async (
  body: Elrond.models.ESDTFreezeData,
  address: string,
  networkProvider: Elrond.models.NetworkProvider
) => {
  const elrondInstance = new Elrond.Client({
    address: address,
    networkProvider,
  });

  const tx = await elrondInstance.buildTransaction({
    transactionCategory: Elrond.models.TransactionCategory.ESDT,
    transactionType: Elrond.models.ESDTFunctions.freeze,
    operationsData: body,
  });

  return tx;
};

export const buildUnFreeze = async (
  body: Elrond.models.ESDTUnFreezeData,
  address: string,
  networkProvider: Elrond.models.NetworkProvider
) => {
  const elrondInstance = new Elrond.Client({
    address: address,
    networkProvider,
  });

  const tx = await elrondInstance.buildTransaction({
    transactionCategory: Elrond.models.TransactionCategory.ESDT,
    transactionType: Elrond.models.ESDTFunctions.unFreeze,
    operationsData: body,
  });

  return tx;
};

export const buildWipe = async (
  body: Elrond.models.ESDTWipe,
  address: string,
  networkProvider: Elrond.models.NetworkProvider
) => {
  const elrondInstance = new Elrond.Client({
    address: address,
    networkProvider,
  });

  const tx = await elrondInstance.buildTransaction({
    transactionCategory: Elrond.models.TransactionCategory.ESDT,
    transactionType: Elrond.models.ESDTFunctions.wipe,
    operationsData: body,
  });

  return tx;
};

export const buildControlChanges = async (
  body: Elrond.models.ESDTControlChanges,
  address: string,
  networkProvider: Elrond.models.NetworkProvider
) => {
  const elrondInstance = new Elrond.Client({
    address: address,
    networkProvider,
  });

  const tx = await elrondInstance.buildTransaction({
    transactionCategory: Elrond.models.TransactionCategory.ESDT,
    transactionType: Elrond.models.ESDTFunctions.controlChanges,
    operationsData: body,
  });

  return tx;
};

export const buildTransferOwnership = async (
  body: Elrond.models.ESDTTransferOwnership,
  address: string,
  networkProvider: Elrond.models.NetworkProvider
) => {
  const elrondInstance = new Elrond.Client({
    address: address,
    networkProvider,
  });

  const tx = await elrondInstance.buildTransaction({
    transactionCategory: Elrond.models.TransactionCategory.ESDT,
    transactionType: Elrond.models.ESDTFunctions.transferOwnership,
    operationsData: body,
  });

  return tx;
};
