import { Bsc } from "@zoidpay-tech/zoidpay-blockchain-helpers";
import { BscScanURL } from "@zoidpay-tech/zoidpay-blockchain-helpers/dist/src/models/Bsc/BscScanUrl";

export const buildTransferBscToken = async (
  body: Bsc.models.BscTokenTransferData,
  address: string,
  networkProvider: Bsc.models.BscNetworkProvider
) => {
  const bsc = new Bsc.Client({
    networkProvider,
    address,
  });

  const web3 = await bsc.establishConnection();

  const tx = await bsc.buildTransation(
    Bsc.models.BscTransactionCategory.BEP20, // to change both in npm package and here to BEP20
    "transferToken",
    body,
    web3
  );

  return tx;
};

export const buildCreateBscToken = async (
  body: Bsc.models.BscTokenCreateData,
  address: string,
  networkProvider: Bsc.models.BscNetworkProvider
) => {
  const bsc = new Bsc.Client({
    networkProvider,
    address,
  });

  const web3 = await bsc.establishConnection();

  const tx = await bsc.buildTransation(
    Bsc.models.BscTransactionCategory.BEP20, // to change both in npm package and here to BEP20
    "createToken",
    body,
    web3
  );

  return tx;
};

export const buildCreateBscNftCollection = async (
  body: Bsc.models.BscNftIssueData,
  address: string,
  networkProvider: Bsc.models.BscNetworkProvider
) => {
  const bsc = new Bsc.Client({
    networkProvider,
    address,
  });

  const web3 = await bsc.establishConnection();

  const tx = await bsc.buildTransation(
    Bsc.models.BscTransactionCategory.BEP721,
    "createNftCollection",
    body,
    web3
  );

  return tx;
};

export const buildmintNftBscTokenCollection = async (
  body: Bsc.models.BscNftMintData,
  address: string,
  networkProvider: Bsc.models.BscNetworkProvider
) => {
  const bsc = new Bsc.Client({
    networkProvider,
    address,
  });

  const web3 = await bsc.establishConnection();

  const tx = await bsc.buildTransation(
    Bsc.models.BscTransactionCategory.BEP721,
    "mintNft",
    body,
    web3
  );

  return tx;
};

export const buildGetAbiFunctionsBsc = async (
  address: string,
  networkProvider: Bsc.models.BscNetworkProvider,
  smartContractAddress: string,
) => {
  const bsc = new Bsc.Client({
    networkProvider,
    address,
  });

  const abiFunctions = await bsc.getAbiFunctions(
    smartContractAddress
  );

  return abiFunctions;
};

export const buildGetAbiBsc = async (
  address: string,
  networkProvider: Bsc.models.BscNetworkProvider,
  smartContractAddress: string
) => {
  const bsc = new Bsc.Client({
    networkProvider,
    address,
  });
  const abiFunctions = await bsc.getAbi(smartContractAddress);

  return abiFunctions;
};

export const buildVerifyBscToken = async (
  body: Bsc.models.VerifyTokenContractBsc,
  address: string,
  networkProvider: Bsc.models.BscNetworkProvider
) => {
  const bsc = new Bsc.Client({
    networkProvider,
    address,
  });

  const tx = await bsc.verifyTokenContract(body);

  return tx;
};

export const buildVerifyBscNft = async (
  body: Bsc.models.VerifyNftContractBsc,
  address: string,
  networkProvider: Bsc.models.BscNetworkProvider
) => {
  const bsc = new Bsc.Client({
    networkProvider,
    address,
  });

  const tx = await bsc.verifyNftContract(body);

  return tx;
};
