import { Ethereum } from "@zoidpay-tech/zoidpay-blockchain-helpers";
import { EtherscanURL } from "@zoidpay-tech/zoidpay-blockchain-helpers/dist/src/models/Ethereum";

export const buildTransferEthToken = async (
  body: Ethereum.models.EthTokenTransferData,
  address: string,
  networkProvider: Ethereum.models.EthereumNetworkProvider,
  chainId: number,
  privateKey: string
) => {
  const ethereum = new Ethereum.Client({
    networkProvider,
    address,
    chainId,
    privateKey,
  });

  const web3 = await ethereum.establishConnection();

  const tx = await ethereum.buildTransation(
    Ethereum.models.EthTransactionCategory.ERC20,
    "transferToken",
    body,
    web3
  );

  return tx;
};

export const buildCreateEthToken = async (
  body: Ethereum.models.EthTokenCreateData,
  address: string,
  networkProvider: Ethereum.models.EthereumNetworkProvider,
  chainId: number,
  privateKey: string
) => {
  const ethereum = new Ethereum.Client({
    networkProvider,
    address,
    chainId,
    privateKey, // refactor to be optional in npm pachage
  });

  const web3 = await ethereum.establishConnection();

  const tx = await ethereum.buildTransation(
    Ethereum.models.EthTransactionCategory.ERC20,
    "createToken",
    body,
    web3
  );

  return tx;
};

export const buildCreateEthTokenCollection = async (
  body: Ethereum.models.EthNftCreateData,
  address: string,
  networkProvider: Ethereum.models.EthereumNetworkProvider,
  chainId: number
) => {
  const ethereum = new Ethereum.Client({
    networkProvider,
    address,
    chainId,
  });

  const web3 = await ethereum.establishConnection();

  const tx = await ethereum.buildTransation(
    Ethereum.models.EthTransactionCategory.ERC721,
    "createNftCollection",
    body,
    web3
  );

  return tx;
};

export const buildmintNftEthTokenCollection = async (
  body: Ethereum.models.EthNftMintData,
  address: string,
  networkProvider: Ethereum.models.EthereumNetworkProvider,
  chainId: number
) => {
  const ethereum = new Ethereum.Client({
    networkProvider,
    address,
    chainId,
  });

  const web3 = await ethereum.establishConnection();

  const tx = await ethereum.buildTransation(
    Ethereum.models.EthTransactionCategory.ERC721,
    "mintNft",
    body,
    web3
  );

  return tx;
};

export const buildVerifyEthNft = async (
  body: Ethereum.models.VerifyNftContractEth,
  address: string,
  networkProvider: Ethereum.models.EthereumNetworkProvider,
  chainId: number
) => {
  const ethereum = new Ethereum.Client({
    networkProvider,
    address,
    chainId,
  });

  const tx = await ethereum.verifyNftContract(body);

  return tx;
};

export const buildVerifyEthToken = async (
  body: Ethereum.models.VerifyTokenContractEth,
  address: string,
  networkProvider: Ethereum.models.EthereumNetworkProvider,
  chainId: number
) => {
  const ethereum = new Ethereum.Client({
    networkProvider,
    address,
    chainId,
  });
  Ethereum.models.VerificationNetworkEth;

  const tx = await ethereum.verifyTokenContract(body);

  return tx;
};

export const abiFunctions = async (
  address: string,
  networkProvider: Ethereum.models.EthereumNetworkProvider,
  chainId: number,
  smartContractAddress: string,
  etherscanURL: EtherscanURL
) => {
  const ethereum = new Ethereum.Client({
    networkProvider,
    address,
    chainId,
  });

  const abiFunctions = await ethereum.getAbiFunctions(
    smartContractAddress,
    etherscanURL
  );

  return abiFunctions;
};

export const buildGetAbiEth = async (
  address: string,
  networkProvider: Ethereum.models.EthereumNetworkProvider,
  chainId: number,
  smartContractAddress: string,
  etherscanURL: EtherscanURL
) => {
  const ethereum = new Ethereum.Client({
    networkProvider,
    address,
    chainId,
  });

  const abiFunctions = await ethereum.getContractAbi(
    smartContractAddress,
    etherscanURL
  );

  return abiFunctions;
};
