import { Polygon } from "@zoidpay-tech/zoidpay-blockchain-helpers";

export const buildTransferMaticToken = async (
  body: Polygon.models.MaticTokenTransferData,
  address: string,
  networkProvider: Polygon.models.MaticNetworkProvider
) => {
  const bsc = new Polygon.Client({
    networkProvider,
    address,
  });

  const web3 = await bsc.establishConnection();

  const tx = await bsc.buildTransation(
    Polygon.models.MaticTransactionCategory.ERC20,
    "transferToken",
    body,
    web3
  );

  return tx;
};

export const buildCreateMaticToken = async (
  body: Polygon.models.MaticTokenCreateData,
  address: string,
  networkProvider: Polygon.models.MaticNetworkProvider
) => {
  const bsc = new Polygon.Client({
    networkProvider,
    address,
  });

  const web3 = await bsc.establishConnection();

  const tx = await bsc.buildTransation(
    Polygon.models.MaticTransactionCategory.ERC20,
    "createToken",
    body,
    web3
  );

  return tx;
};

export const buildMaticTokenVerify = async (
  body: Polygon.models.MaticVerifyTokenContract,
  address: string,
  networkProvider: Polygon.models.MaticNetworkProvider
) => {
  try {
    const polygon = new Polygon.Client({
      networkProvider,
      address,
    });

    await polygon.verifyTokenContract(body);

    return "Your token was verified";
  } catch (err: any) {
    return "Your token could not be verified. Please check if your contract was deployed with our services or if the input you provided is correct.";
  }
};

export const buildCreateNftMaticCollection = async (
  body: Polygon.models.MaticNftCreateData,
  address: string,
  networkProvider: Polygon.models.MaticNetworkProvider
) => {
  const bsc = new Polygon.Client({
    networkProvider,
    address,
  });

  const web3 = await bsc.establishConnection();

  const tx = await bsc.buildTransation(
    Polygon.models.MaticTransactionCategory.ERC721,
    "createNftCollection",
    body,
    web3
  );

  return tx;
};

export const buildMaticMintToken = async (
  body: Polygon.models.MaticNftMintData,
  address: string,
  networkProvider: Polygon.models.MaticNetworkProvider
) => {
  const bsc = new Polygon.Client({
    networkProvider,
    address,
  });

  const web3 = await bsc.establishConnection();

  const tx = await bsc.buildTransation(
    Polygon.models.MaticTransactionCategory.ERC721,
    "mintNft",
    body,
    web3
  );

  return tx;
};

export const buildMaticNftVerify = async (
  body: Polygon.models.MaticVerifySmartContractNft,
  address: string,
  networkProvider: Polygon.models.MaticNetworkProvider
) => {
  try {
    const polygon = new Polygon.Client({
      networkProvider,
      address,
    });

    await polygon.verifyNftContract(body);

    return "Your token was verified";
  } catch (err: any) {
    return "Your token could not be verified. Please check if your contract was deployed with our services or if the input you provided is correct.";
  }
};

export const buildGetAbiMatic = async (
  address: string,
  networkProvider: Polygon.models.MaticNetworkProvider,
  smartContractAddress: string,
) => {
  try {
    const polygon = new Polygon.Client({
      networkProvider,
      address,
    });

    const tx = await polygon.getContractAbi(
      smartContractAddress,
    );

    return tx;
  } catch (err: any) {
    return "Could not retrieve ABI";
  }
};