import { Elrond } from "@zoidpay-tech/zoidpay-blockchain-helpers";

export const buildCreateNft = async (
  body: Elrond.models.ESDTNFTCreate,
  address: string,
  networkProvider: Elrond.models.NetworkProvider
) => {
  const elrondInstance = new Elrond.Client({
    address: address,
    networkProvider: networkProvider,
  });

  const tx = await elrondInstance.buildTransaction({
    transactionCategory: Elrond.models.TransactionCategory.NFT,
    transactionType: Elrond.models.NFTFunctions.ESDTNFTCreate,
    operationsData: body,
  });

  return tx;
};

export const buildTransferNft = async (
  body: Elrond.models.ESDTNFTTransfer,
  address: string,
  networkProvider: Elrond.models.NetworkProvider
) => {
  const elrondInstance = new Elrond.Client({
    address: address,
    networkProvider: networkProvider,
  });
  const tx = await elrondInstance.buildTransaction({
    transactionCategory: Elrond.models.TransactionCategory.NFT,
    transactionType: Elrond.models.NFTFunctions.ESDTNFTTransfer,
    operationsData: body,
  });

  return tx;
};

export const buildIssueNft = async (
  body: Elrond.models.NFTIssueData,
  address: string,
  networkProvider: Elrond.models.NetworkProvider
) => {
  const elrondInstance = new Elrond.Client({
    address: address,
    networkProvider: networkProvider,
  });

  const tx = await elrondInstance.buildTransaction({
    transactionCategory: Elrond.models.TransactionCategory.NFT,
    transactionType: Elrond.models.NFTFunctions.issueNonFungible,
    operationsData: body,
  });

  return tx;
};

export const buildSetSpecialRoleNft = async (
  body: Elrond.models.NFTSetSpecialRoleData,
  address: string,
  networkProvider: Elrond.models.NetworkProvider
) => {
  const elrondInstance = new Elrond.Client({
    address: address,
    networkProvider: networkProvider,
  });

  const tx = await elrondInstance.buildTransaction({
    transactionCategory: Elrond.models.TransactionCategory.NFT,
    transactionType: Elrond.models.NFTFunctions.setSpecialRole,
    operationsData: body,
  });

  return tx;
};

export const buildTransferNftCreateRole = async (
  body: Elrond.models.NFTTransferCreateRole,
  address: string,
  networkProvider: Elrond.models.NetworkProvider
) => {
  const elrondInstance = new Elrond.Client({
    address: address,
    networkProvider: networkProvider,
  });

  const tx = await elrondInstance.buildTransaction({
    transactionCategory: Elrond.models.TransactionCategory.NFT,
    transactionType: Elrond.models.NFTFunctions.transferNFTCreateRole,
    operationsData: body,
  });

  return tx;
};

export const buildStopNftCreate = async (
  body: Elrond.models.NFTStopNftCreate,
  address: string,
  networkProvider: Elrond.models.NetworkProvider
) => {
  const elrondInstance = new Elrond.Client({
    address: address,
    networkProvider: networkProvider,
  });

  const tx = await elrondInstance.buildTransaction({
    transactionCategory: Elrond.models.TransactionCategory.NFT,
    transactionType: Elrond.models.NFTFunctions.stopNFTCreate,
    operationsData: body,
  });

  return tx;
};

export const buildUpdateAttributes = async (
  body: Elrond.models.ESDTNFTUpdateAttributesData,
  address: string,
  networkProvider: Elrond.models.NetworkProvider
) => {
  const elrondInstance = new Elrond.Client({
    address: address,
    networkProvider: networkProvider,
  });

  const tx = await elrondInstance.buildTransaction({
    transactionCategory: Elrond.models.TransactionCategory.NFT,
    transactionType: Elrond.models.NFTFunctions.ESDTNFTUpdateAttributes,
    operationsData: body,
  });

  return tx;
};

export const buildNftAddURI = async (
  body: Elrond.models.ESDTNFTAddURI,
  address: string,
  networkProvider: Elrond.models.NetworkProvider
) => {
  const elrondInstance = new Elrond.Client({
    address: address,
    networkProvider: networkProvider,
  });

  const tx = await elrondInstance.buildTransaction({
    transactionCategory: Elrond.models.TransactionCategory.NFT,
    transactionType: Elrond.models.NFTFunctions.ESDTNFTAddURI,
    operationsData: body,
  });

  return tx;
};

export const buildFreezeSingleNFT = async (
  body: Elrond.models.ESDTfreezeSingleNFT,
  address: string,
  networkProvider: Elrond.models.NetworkProvider
) => {
  const elrondInstance = new Elrond.Client({
    address: address,
    networkProvider: networkProvider,
  });

  const tx = await elrondInstance.buildTransaction({
    transactionCategory: Elrond.models.TransactionCategory.NFT,
    transactionType: Elrond.models.NFTFunctions.freezeSingleNFT,
    operationsData: body,
  });

  return tx;
};

export const buildUnFreezeSingleNFT = async (
  body: Elrond.models.ESDTUnFreezeSingleNFT,
  address: string,
  networkProvider: Elrond.models.NetworkProvider
) => {
  const elrondInstance = new Elrond.Client({
    address: address,
    networkProvider: networkProvider,
  });

  const tx = await elrondInstance.buildTransaction({
    transactionCategory: Elrond.models.TransactionCategory.NFT,
    transactionType: Elrond.models.NFTFunctions.unFreezeSingleNFT,
    operationsData: body,
  });

  return tx;
};

export const buildwipeSingleNFT = async (
  body: Elrond.models.ESDTwipeSingleNFT,
  address: string,
  networkProvider: Elrond.models.NetworkProvider
) => {
  const elrondInstance = new Elrond.Client({
    address: address,
    networkProvider: networkProvider,
  });

  const tx = await elrondInstance.buildTransaction({
    transactionCategory: Elrond.models.TransactionCategory.NFT,
    transactionType: Elrond.models.NFTFunctions.wipeSingleNFT,
    operationsData: body,
  });

  return tx;
};
