/*
 Checks if payload is valid and throws error if it is not.
 */
import { NextFunction } from "express";
import { Request, Response } from "express";
import { Elrond } from "@zoidpay-tech/zoidpay-blockchain-helpers";

export const nftUnfreezeSingleNftValidator = (
  req: Request,
  res: Response,
  next: NextFunction
) => {
  const payload = req.body;

  if (!payload.address)
    throw new Error("The `address` parameter is not present.");
  if (!payload.tokenIdentifier)
    throw new Error("The `tokenName` parameter is not present.");
  if (!payload.nftNonce && !isNaN(payload.nftNonce))
    throw new Error("The `nftNonce` parameter is not present.");
  if (!payload.accountAddressToUnFreeze)
    throw new Error("The `accountAddressToUnFreeze` parameter is not present.");
  if (!payload.networkProvider)
    throw new Error(
      `The 'networkProvider' parameter is not present. Please provide one of the following network providers: '${Elrond.models.NetworkProvider.devnet}', '${Elrond.models.NetworkProvider.mainnet}', '${Elrond.models.NetworkProvider.testnet}'`
    );
  next();
};
