/*
 Checks if payload is valid and throws error if it is not.
 */
import { NextFunction } from "express";
import { Request, Response } from "express";
import { Elrond } from "@zoidpay-tech/zoidpay-blockchain-helpers";

export const sftCreateValidator = (
  req: Request,
  res: Response,
  next: NextFunction
) => {
  const payload = req.body;

  if (!payload.address)
    throw new Error("The `address` parameter is not present.");
  if (!payload.tokenIdentifier)
    throw new Error("The `tokenIdentifier` parameter is not present.");
  if (!payload.nftNonce)
    throw new Error("The `nftNonce` parameter is not present.");
  if (!payload.initialQuantity)
    throw new Error(
      "The `initialQuantity` parameter is not present or is not a number."
    );
  if (!payload.nftName)
    throw new Error(
      "The `nftName` parameter is not present or is not a number."
    );
  if (!payload.royalties)
    throw new Error(
      "The `royalties` parameter is not present or is not a number."
    );
  if (!payload.addressToSendTo)
    throw new Error("The `addressToSendTo` parameter is not present.");
  if (!payload.URILinks)
    throw new Error("The `URILinks` parameter is not present.");
  if (!payload.senderAddress)
    throw new Error("The `senderAddress` parameter is not present.");
  if (!payload.hash) throw new Error("The `hash` parameter is not present.");
  if (!payload.attributes)
    throw new Error("The `attributes` parameter is not present.");

  if (!payload.networkProvider)
    throw new Error(
      `The 'networkProvider' parameter is not present. Please provide one of the following network providers: '${Elrond.models.NetworkProvider.devnet}', '${Elrond.models.NetworkProvider.mainnet}', '${Elrond.models.NetworkProvider.testnet}'`
    );
  next();
};
